@@ -49,6 +49,15 @@ Options:
         Limit output to job-id(s).
         Option may be repeated. Search by regex.
 
+    --root=<NAME>
+        Filter jobs whose workdir has this root.
+
+    -C, --cwd
+        Same as ``--root .``.
+
+    -D, --max-depth=<N>
+        Filter jobs whose workdir has maximally this depth compared to ``--root``.
+
     --host=<NAME>
         Limit output to host(s).
         Option may be repeated. Search by regex.
@@ -127,6 +136,10 @@ Options:
     --debug=<FILE>
         Debug: read ``squeue -o "%all"`` from file.
 
+    -d, --print-dependency
+        Print the selected jobs as ``-d <jobid> -d <jobid> ...``.
+        Use to for example ``Gsub *slurm `Gstat -d -U --partition "serial"```.
+
     -h, --help
         Show help.
 
@@ -140,6 +153,8 @@ import os
 import pwd
 import re
 
+import numpy as np
+
 from .. import rich
 from .. import squeue
 from .. import table
@@ -167,6 +182,9 @@ class Gstat:
         parser.add_argument("-u", "--user", type=str, action="append", default=[])
         parser.add_argument("-j", "--jobid", type=str, action="append", default=[])
         parser.add_argument("--host", type=str, action="append")
+        parser.add_argument("--root", type=str)
+        parser.add_argument("-C", "--cwd", action="store_true")
+        parser.add_argument("-D", "--max-depth", type=int)
         parser.add_argument("-a", "--account", type=str, action="append")
         parser.add_argument("-n", "--name", type=str, action="append")
         parser.add_argument("-w", "--workdir", type=str, action="append")
@@ -189,6 +207,7 @@ class Gstat:
         parser.add_argument("--sep", type=str, default=" ")
         parser.add_argument("--long", action="store_true")
         parser.add_argument("--debug", type=str)
+        parser.add_argument("-d", "--print-dependency", action="store_true")
         parser.add_argument("--version", action="version", version=version)
         parser.add_argument("jobs", type=int, nargs="*")
 
@@ -200,12 +219,22 @@ class Gstat:
         if args["U"]:
             args["user"] += [pwd.getpwuid(os.getuid())[0]]
 
+        if args["cwd"]:
+            assert not args["root"]
+            args["root"] = "."
+
         if args["joblist"]:
             args["output"] = ["JOBID"]
             args["list"] = True
 
         args["jobid"] += [f"^{i:d}$" for i in args["jobs"]]
 
+        if args["root"] or args["max_depth"]:
+            if args["extra"] is None:
+                args["extra"] = ["WorkDir"]
+            elif "WorkDir" not in args["extra"]:
+                args["extra"] += ["WorkDir"]
+
         # store for later use
         self.args = args
 
@@ -236,6 +265,7 @@ class Gstat:
             "PARTITION": "Partition",
             "DEPENDENCY": "Dependency",
             "WORK_DIR": "WorkDir",
+            "COMMAND": "Command",
         }
 
         # conversion map: custom field-names -> default field-names
@@ -271,6 +301,7 @@ class Gstat:
             {"key": "NODELIST(REASON)", "width": 5, "align": "<", **noprio},
             {"key": "DEPENDENCY", "width": 5, "align": "<", **nodefault},
             {"key": "WORK_DIR", "width": 7, "align": "<", **nodefault},
+            {"key": "COMMAND", "width": 7, "align": "<", **nodefault},
         ]
 
         # header
@@ -279,6 +310,9 @@ class Gstat:
             for column in columns
         }
 
+        if self.args["root"]:
+            header["WORK_DIR"] = rich.String(header["WORK_DIR"].data + " " + self.args["root"])
+
         # select color theme
         theme = squeue.colors(self.args["colors"].lower())
 
@@ -298,16 +332,41 @@ class Gstat:
 
         # -- convert paths ---
 
-        if self.args["abspath"]:
+        if self.args["root"]:
+            root = self.args["root"]
+            lines = [
+                i for i in lines if not os.path.relpath(i["WORK_DIR"].data, root).startswith("..")
+            ]
             for line in lines:
-                line["WORK_DIR"].data = os.path.abspath(line["WORK_DIR"].data)
-        elif self.args["relpath"]:
-            for line in lines:
-                line["WORK_DIR"].data = os.path.relpath(line["WORK_DIR"].data)
-        else:
-            for line in lines:
-                if len(os.path.relpath(line["WORK_DIR"].data).split("../")) < 3:
+                line["WORK_DIR"].data = os.path.relpath(line["WORK_DIR"].data, root)
+                line["COMMAND"].data = os.path.relpath(line["COMMAND"].data, root)
+            if self.args["max_depth"]:
+                lines = [
+                    line
+                    for line in lines
+                    if len(line["WORK_DIR"].data.split(os.path.sep)) <= self.args["max_depth"]
+                ]
+        elif self.args["max_depth"]:
+            lines = [
+                line
+                for line in lines
+                if len(line["WORK_DIR"].data.split(os.path.sep)) <= self.args["max_depth"] + 1
+            ]
+
+        if not self.args["root"]:
+            if self.args["abspath"]:
+                for line in lines:
+                    line["WORK_DIR"].data = os.path.abspath(line["WORK_DIR"].data)
+                    line["COMMAND"].data = os.path.abspath(line["COMMAND"].data)
+            elif self.args["relpath"]:
+                for line in lines:
                     line["WORK_DIR"].data = os.path.relpath(line["WORK_DIR"].data)
+                    line["COMMAND"].data = os.path.relpath(line["COMMAND"].data)
+            else:
+                for line in lines:
+                    if len(os.path.relpath(line["WORK_DIR"].data).split("../")) < 3:
+                        line["WORK_DIR"].data = os.path.relpath(line["WORK_DIR"].data)
+                        line["COMMAND"].data = os.path.relpath(line["COMMAND"].data)
 
         # -- limit based on command-line options --
 
@@ -339,17 +398,30 @@ class Gstat:
             # - apply to the header
             header[key].color = theme["selection"]
 
+        if self.args["root"] or self.args["max_depth"]:
+            key = "WORK_DIR"
+
+            for line in lines:
+                line[key].color = theme["selection"]
+
+            header[key].color = theme["selection"]
+
         # -- sort --
 
-        # default sort
-        lines.sort(key=lambda line: line["START_TIME"], reverse=not self.args["reverse"])
-
-        # optional: sort by key(s)
         if self.args["sort"]:
-            for key in self.args["sort"]:
-                lines.sort(
-                    key=lambda line: line[aliasInv[key.upper()]], reverse=self.args["reverse"]
-                )
+            sortkeys = [aliasInv[key.upper()] for key in self.args["sort"]]
+            reversed = False
+        else:
+            sortkeys = ["JOBID", "PARTITION"]
+            reversed = False
+
+        if self.args["reverse"]:
+            reversed = not reversed
+
+        idx = np.lexsort([[i[key] for i in lines] for key in sortkeys])
+        if reversed:
+            idx = idx[::-1]
+        lines = [lines[i] for i in idx]
 
         # -- select columns --
 
@@ -364,8 +436,7 @@ class Gstat:
             columns = [column for column in columns if column["key"] in keys]
         else:
             columns = [column for column in columns if column["default"]]
-
-        columns += extra
+            columns += extra
 
         # store for later use
         self.lines = lines
@@ -392,6 +463,7 @@ class Gstat:
                 raise OSError("Error: Only one field can be selected")
 
             table.print_list(self.lines, self.columns[0]["key"], self.args["sep"])
+            return
 
         # print columns
         table.print_columns(
@@ -493,18 +565,17 @@ class Gstat:
         Print.
         """
 
-        if not self.args["summary"]:
+        if self.args["print_dependency"]:
+            if len(self.lines) > 0:
+                print("-d " + " -d ".join([str(line["JOBID"]) for line in self.lines]))
+        elif not self.args["summary"]:
             self.print_all()
         else:
             self.print_summary()
 
 
-def main():
-    try:
-        p = Gstat()
-        p.parse_cli_args()
-        p.read()
-        p.print()
-    except Exception as e:
-        print(e)
-        return 1
+def main(cli_args: list[str] = None):
+    p = Gstat()
+    p.parse_cli_args(cli_args)
+    p.read()
+    p.print()
