@@ -10,6 +10,8 @@ import subprocess
 import sys
 from collections import defaultdict
 
+import numpy as np
+
 from . import duration
 from . import rich
 from . import table
@@ -88,6 +90,10 @@ def cli_parser() -> argparse.ArgumentParser:
     *   The following column abbreviations are used (depending on the output):
         -  ``State``: ``ST``
         -  ``ExitCode``: ``exit``
+
+    .. tip::
+
+        Use ``seff jobid`` to get more information, such as memory usage.
     """
 
     parser = argparse.ArgumentParser(
@@ -98,8 +104,12 @@ def cli_parser() -> argparse.ArgumentParser:
     parser.add_argument("-X", "--allocations", action="store_true", help="Include only main job.")
     parser.add_argument("-j", "--json", action="store_true", help="Print in JSON format.")
     parser.add_argument("--sep", type=str, default=" ", help="Column separator.")
+    parser.add_argument("--no-truncate", action="store_true", help="Print without fitting screen.")
     parser.add_argument("--sort", help="Sort based on column.", **append)
     parser.add_argument("--reverse", action="store_true", help="Reverse order.")
+    parser.add_argument("--no-header", action="store_true", help="Do not print header.")
+    parser.add_argument("--width", type=int, help="Print width (default: read from terminal).")
+    parser.add_argument("-o", "--output", type=str, action="append", help="Output columns.")
     parser.add_argument("--infer", type=str, help="Read extra data from ``JOBID.infer``.")
     parser.add_argument("-e", "--extra", help="Extra columns.", **append)
     parser.add_argument(
@@ -108,6 +118,12 @@ def cli_parser() -> argparse.ArgumentParser:
     parser.add_argument(
         "--relpath", action="store_true", help="Print directories as relative (default: automatic)."
     )
+    parser.add_argument(
+        "--root",
+        type=str,
+        help="Filter jobs whose WorkDir has this root (WorkDir printed relative to this root).",
+    )
+    parser.add_argument("-C", "--cwd", action="store_true", help="Same as ``--root .``.")
     parser.add_argument(
         "-L", "--allclusters", action="store_true", help="Display jobs ran on all clusters."
     )
@@ -150,6 +166,15 @@ def Gacct(args: list[str]):
 
     parser = cli_parser()
     args = parser.parse_args(args)
+    extra = [i for i in args.extra]
+
+    if args.cwd:
+        assert not args.root
+        args.root = "."
+
+    if args.root is not None:
+        if "WorkDir" not in extra:
+            extra += ["WorkDir"]
 
     opts = ["-p", "-l"]
     if args.allocations:
@@ -207,14 +232,18 @@ def Gacct(args: list[str]):
 
     lines = _read(" ".join(["sacct"] + opts))
 
-    if args.extra:
-        op = [i for i in opts] + ["--format", ",".join(args.extra)]
+    if extra:
+        op = [i for i in opts] + ["--format", ",".join(extra)]
         op.remove("-l")
-        extra = _read(" ".join(["sacct"] + op))
+        ex = _read(" ".join(["sacct"] + op))
         for i in range(len(lines)):
-            lines[i] = {**lines[i], **extra[i]}
+            lines[i] = {**lines[i], **ex[i]}
 
-    if "WorkDir" in args.extra:
+    if args.root:
+        lines = [i for i in lines if not os.path.relpath(i["WorkDir"], args.root).startswith("..")]
+        for line in lines:
+            line["WorkDir"] = os.path.relpath(line["WorkDir"], args.root)
+    elif "WorkDir" in extra:
         if args.abspath:
             for line in lines:
                 line["WorkDir"] = os.path.abspath(line["WorkDir"])
@@ -230,9 +259,9 @@ def Gacct(args: list[str]):
         if not args.allocations:
             raise ValueError("Cannot infer extra data without --allocations.")
         opts.remove("-X")
-        extra = _read(" ".join(["sacct"] + opts))
+        ex = _read(" ".join(["sacct"] + opts))
         data = defaultdict(dict)
-        for line in extra:
+        for line in ex:
             if "." not in line["JobID"]:
                 continue
             jobid, key = line["JobID"].split(".")
@@ -275,21 +304,12 @@ def Gacct(args: list[str]):
             if sum(1 if re.match(n, str(line[key]), re.IGNORECASE) else 0 for n in fields)
         ]
 
-    # shorten state
-    shorten = {"COMPLETED": "C", "RUNNING": "R", "FAILED": "F"}
-    shorten_state = True
-    for i in list({i["State"] for i in lines}):
-        if i not in shorten:
-            shorten_state = False
-            break
-    if shorten_state:
-        for line in lines:
-            line["State"] = shorten[line["State"]]
-
     if args.sort:
-        lookup = {i.lower(): i for i in lines[0].keys()}
-        for key in args.sort:
-            lines.sort(key=lambda line: line[lookup[key]], reverse=args.reverse)
+        lookup = {i.upper(): i for i in lines[0].keys()}
+        idx = np.lexsort([[line[lookup[key.upper()]] for line in lines] for key in args.sort])
+        if args.reverse:
+            idx = idx[::-1]
+        lines = [lines[i] for i in idx]
     elif args.reverse:
         lines = [i for i in lines[::-1]]
 
@@ -317,7 +337,7 @@ def Gacct(args: list[str]):
         "AveDiskWrite",
         "MaxVMSizeNode",
         "MaxVMSize",
-    ] + args.extra
+    ] + extra
     default = sorted(set(default), key=lambda x: default.index(x))
 
     columns = [{"key": key, "width": len(key), "align": ">", "priority": True} for key in default]
@@ -330,7 +350,7 @@ def Gacct(args: list[str]):
     columns[default.index("JobName")]["align"] = "<"
     columns[default.index("State")]["align"] = "<"
     columns[default.index("Partition")]["align"] = "<"
-    if "WorkDir" in args.extra:
+    if "WorkDir" in extra:
         columns[default.index("WorkDir")]["align"] = "<"
 
     for i in range(len(lines)):
@@ -353,13 +373,20 @@ def Gacct(args: list[str]):
         columns = [c for c, k in zip(columns, keep) if k]
         default = [c for c, k in zip(default, keep) if k]
 
-    if shorten_state:
-        header["State"] = "ST"
-        columns[default.index("State")]["width"] = 2
-        header["ExitCode"] = "exit"
-        columns[default.index("ExitCode")]["width"] = 4
+    if args.output:
+        alias = {c["key"].upper(): c["key"] for c in columns}
+        keys = [alias[key.upper()] for key in args.output]
+        columns = [column for column in columns if column["key"] in keys]
 
-    table.print_columns(lines, columns, header, sep=args.sep)
+    table.print_columns(
+        lines=lines,
+        columns=columns,
+        header=header,
+        sep=args.sep,
+        no_truncate=args.no_truncate,
+        cols=args.width,
+        print_header=not args.no_header,
+    )
 
 
 def _Gacct_catch():
